@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
-# template 17
+# template 18
 """
 Python supplemental features
 ----------------------------
 
 python_plus adds various features to python 2 and python 3 programs.
-It is designed to be used as integration of pypi future to help to port your code from Python 2 to Python 3 and still have it run on Python 2.
+It is designed to be used as integration of pypi future to help to port
+your code from Python 2 to Python 3 and still have it run on Python 2.
 
 
 vem: virtual environment manager
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This package is released with an nice command:
-**vem** that is an interactive tool with some nice features to manage standard virtual environment and it is osx/darwin compatible.
+**vem** that is an interactive tool with some nice features to manage
+standard virtual environment and it is osx/darwin compatible.
 """
 import os
 import sys
@@ -21,7 +23,7 @@ import gzip
 import shutil
 
 
-__version__ = '1.0.7'
+__version__ = '1.0.8'
 
 
 def fake_setup(**kwargs):
@@ -94,7 +96,10 @@ def copy_pkg_data(setup_args, verbose):
                             help_text = fd.read()
                         tgt_fn = os.path.join(man_path, '%s.8.gz' % base[:-4])
                         with gzip.open(tgt_fn, 'w') as fd:
-                            fd.write(help_text)
+                            if sys.version_info[0] == 3:
+                                fd.write(help_text.encode('utf-8'))
+                            else:
+                                fd.write(help_text)
                         continue
                     if lib_path:
                         tgt_fn = os.path.join(lib_path, base)
@@ -153,4 +158,4 @@ def main(cli_args=None):
             print(text)
     elif action in ('-C', '--copy-pkg-data'):
         copy_pkg_data(setup_args, verbose)
-    return 0
+    return 0
\ No newline at end of file
