@@ -12,9 +12,12 @@ import ast
 import os
 import sys
 
-from .git_run import GitRun
+if sys.version_info[0] == 2:
+    from git_run import GitRun
+else:
+    from .git_run import GitRun
 
-__version__ = '1.0.7'
+__version__ = '1.0.8'
 
 MANIFEST_FILES = [
     '__manifest__.py',
@@ -249,4 +252,4 @@ def main(argv=None):
 
 
 if __name__ == "__main__":
-    sys.exit(main())
+    sys.exit(main())
\ No newline at end of file
